@@ -19,7 +19,9 @@
 #include "mime-application.h"
 #include "mime-action.h"
 #include "transfer-progress.h"
+#include "transfer-progress-2.h"
 #include "async-handle.h"
+#include "async-handle-2.h"
 #include "drive.h"
 #include "volume.h"
 #include "volume-monitor.h"
